==> fred_inquisitor-1.0.0rc3-py3-none-any.whl: inquisitor/tests/test_contact.py <==
from unittest.mock import call

from fred_types import DomainId, DomainRef
from regal import Contact, DomainContactRole
from regal.exceptions import ContactDoesNotExist, RegistrarDoesNotExist
from verifier import PaginatedList, Verification, VerificationStatus
from verifier.exceptions import IncorrectStatus

from inquisitor.constants import LogEntryType, LoggerResult, LogReferenceType, MessageType
from inquisitor.contact import RegistrarPublicInfo

from .utils import (
    CONTACT_ID,
    VERIFICATION_ID,
    ApiTestCase,
    make_contact,
    make_registrar,
    make_verification,
)


class GetTest(ApiTestCase):
    async def test_get(self):
        contact = make_contact()
        self.contact_client.get_contact_info.return_value = contact
        response = self.client.get("/contact/")
        self.assertEqual(response.status_code, 200)
        self.assertEqual(Contact(**response.json()), contact)
        self.assertEqual(self.contact_client.mock_calls, [call.get_contact_info(CONTACT_ID)])

    async def test_get_verification_not_found(self):
        self.contact_client.get_contact_info.side_effect = ContactDoesNotExist
        response = self.client.get("/contact/")
        self.assertEqual(response.status_code, 404)
        self.assertEqual(response.json(), {"detail": "Contact not found"})
        self.assertEqual(self.contact_client.mock_calls, [call.get_contact_info(CONTACT_ID)])


class GetDomainsTest(ApiTestCase):
    async def test_get_domains(self):
        self.domain_client.get_domains_by_contact.return_value = {
            "domains": [
                {"domain": DomainRef(id=DomainId("c:1"), fqdn="lister.example.com")},
                {"domain": DomainRef(id=DomainId("c:2"), fqdn="rimmer.example.com")},
            ],
            "pagination": None,
        }
        response = self.client.get("/contact/domains/")
        self.assertEqual(response.status_code, 200)
        self.assertEqual(
            response.json(),
            {"results": ["lister.example.com", "rimmer.example.com"], "pagination": None},
        )
        self.assertEqual(
            self.domain_client.mock_calls,
            [
                call.get_domains_by_contact(
                    CONTACT_ID,
                    roles={DomainContactRole.HOLDER},
                    include_deleted=False,
                    order_by="fqdn",
                    page_size=None,
                    page_token=None,
                )
            ],
        )

    async def test_get_domains_contact_not_found(self):
        self.domain_client.get_domains_by_contact.side_effect = ContactDoesNotExist
        response = self.client.get("/contact/domains/")
        self.assertEqual(response.status_code, 404)
        self.assertEqual(response.json(), {"detail": "Contact not found"})
        self.assertEqual(
            self.domain_client.mock_calls,
            [
                call.get_domains_by_contact(
                    CONTACT_ID,
                    roles={DomainContactRole.HOLDER},
                    include_deleted=False,
                    order_by="fqdn",
                    page_size=None,
                    page_token=None,
                )
            ],
        )


class GetRegistrar(ApiTestCase):
    async def test_get_registrar(self):
        contact = make_contact()
        registrar = make_registrar()
        self.contact_client.get_contact_info.return_value = contact
        self.registrar_client.get_registrar_info.return_value = registrar
        response = self.client.get("/contact/registrar/")
        self.assertEqual(response.status_code, 200)
        self.assertEqual(
            RegistrarPublicInfo(**response.json()),
            RegistrarPublicInfo(**registrar.dict()),
        )
        self.assertEqual(
            self.registrar_client.mock_calls,
            [call.get_registrar_info(contact.sponsoring_registrar)],
        )

    async def test_get_registrar_contact_not_found(self):
        self.contact_client.get_contact_info.side_effect = ContactDoesNotExist
        response = self.client.get("/contact/registrar/")
        self.assertEqual(response.status_code, 404)
        self.assertEqual(response.json(), {"detail": "Contact not found"})
        self.assertEqual(self.contact_client.mock_calls, [call.get_contact_info(CONTACT_ID)])
        self.assertEqual(self.registrar_client.mock_calls, [])

    async def test_get_registrar_registrar_not_found(self):
        contact = make_contact()
        self.contact_client.get_contact_info.return_value = contact
        self.registrar_client.get_registrar_info.side_effect = RegistrarDoesNotExist
        response = self.client.get("/contact/registrar/")
        self.assertEqual(response.status_code, 404)
        self.assertEqual(response.json(), {"detail": "Registrar not found"})
        self.assertEqual(self.contact_client.mock_calls, [call.get_contact_info(CONTACT_ID)])
        self.assertEqual(
            self.registrar_client.mock_calls,
            [call.get_registrar_info(contact.sponsoring_registrar)],
        )


class ResendInitialMessageTest(ApiTestCase):
    def setUp(self):
        super().setUp()
        self.list_call = call.list(
            contact_id=CONTACT_ID,
            statuses={
                VerificationStatus.UNKNOWN,
                VerificationStatus.CREATED,
                VerificationStatus.INITIALIZED,
                VerificationStatus.ACCESSED,
                VerificationStatus.PENDING,
                VerificationStatus.CONSTRAINED,
                VerificationStatus.FUTILE,
            },
        )

    async def test_resend_initial_message(self):
        self.contact_client.get_contact_id.return_value = CONTACT_ID
        self.verification_client.list.return_value = PaginatedList[Verification](
            results=[make_verification()]
        )
        self.verification_client.resend_message.return_value = None

        response = self.client.post("/contact/resend_initial/?contact_handle=KRYTEN")

        self.assertEqual(response.status_code, 200)
        self.assertEqual(self.contact_client.mock_calls, [call.get_contact_id("KRYTEN")])
        self.assertEqual(
            self.verification_client.mock_calls,
            [
                self.list_call,
                call.resend_message(VERIFICATION_ID, message_type=MessageType.INITIAL),
            ],
        )
        self.assertLog(
            LogEntryType.RESEND_MESSAGE,
            LoggerResult.SUCCESS,
            input_properties={"contact_handle": "KRYTEN", "type": MessageType.INITIAL.value},
            output_properties={"message_sent": str(True)},
            output_references={
                LogReferenceType.CONTACT: CONTACT_ID,
                LogReferenceType.VERIFICATION: VERIFICATION_ID,
            },
        )

    async def test_resend_initial_message_no_verification(self):
        self.contact_client.get_contact_id.return_value = CONTACT_ID
        self.verification_client.list.return_value = PaginatedList[Verification](results=[])

        response = self.client.post("/contact/resend_initial/?contact_handle=KRYTEN")

        self.assertEqual(response.status_code, 200)
        self.assertEqual(self.contact_client.mock_calls, [call.get_contact_id("KRYTEN")])
        self.assertEqual(self.verification_client.mock_calls, [self.list_call])
        self.assertLog(
            LogEntryType.RESEND_MESSAGE,
            LoggerResult.SUCCESS,
            input_properties={"contact_handle": "KRYTEN", "type": MessageType.INITIAL.value},
            output_properties={"message_sent": str(False)},
            output_references={
                LogReferenceType.CONTACT: CONTACT_ID,
            },
        )

    async def test_contact_not_found(self):
        self.contact_client.get_contact_id.side_effect = ContactDoesNotExist

        response = self.client.post("/contact/resend_initial/?contact_handle=KRYTEN")

        self.assertEqual(response.status_code, 404)
        self.assertEqual(response.json(), {"detail": "Contact not found"})
        self.assertEqual(self.contact_client.mock_calls, [call.get_contact_id("KRYTEN")])
        self.assertEqual(self.verification_client.mock_calls, [])
        self.assertLog(
            LogEntryType.RESEND_MESSAGE,
            LoggerResult.FAIL,
            input_properties={"contact_handle": "KRYTEN", "type": MessageType.INITIAL.value},
            output_properties={"message_sent": str(False), "error": "Contact not found"},
        )

    async def test_incorrect_status(self):
        self.contact_client.get_contact_id.return_value = CONTACT_ID
        self.verification_client.list.return_value = PaginatedList[Verification](
            results=[make_verification()]
        )
        self.verification_client.resend_message.side_effect = IncorrectStatus

        response = self.client.post("/contact/resend_initial/?contact_handle=KRYTEN")

        self.assertEqual(response.status_code, 200)
        self.assertEqual(self.contact_client.mock_calls, [call.get_contact_id("KRYTEN")])
        self.assertEqual(
            self.verification_client.mock_calls,
            [
                self.list_call,
                call.resend_message(VERIFICATION_ID, message_type=MessageType.INITIAL),
            ],
        )
        self.assertLog(
            LogEntryType.RESEND_MESSAGE,
            LoggerResult.FAIL,
            input_properties={"contact_handle": "KRYTEN", "type": MessageType.INITIAL.value},
            output_properties={
                "message_sent": str(False),
                "error": "Incorrect verification status",
            },
            output_references={
                LogReferenceType.CONTACT: CONTACT_ID,
                LogReferenceType.VERIFICATION: VERIFICATION_ID,
            },
        )

==> fred_inquisitor-1.3.0rc1-py3-none-any.whl: inquisitor/tests/test_contact.py <==
from unittest.mock import call

from fred_types import DomainId, DomainRef
from regal import Contact, DomainContactRole
from regal.exceptions import ContactDoesNotExist, RegistrarDoesNotExist
from verifier import PaginatedList, Verification, VerificationStatus
from verifier.exceptions import IncorrectStatus

from inquisitor.constants import LogEntryType, LoggerResult, LogReferenceType, MessageType
from inquisitor.contact import RegistrarPublicInfo

from .utils import (
    CONTACT_ID,
    VERIFICATION_ID,
    ApiTestCase,
    make_contact,
    make_registrar,
    make_verification,
)


class GetTest(ApiTestCase):
    async def test_get(self):
        contact = make_contact()
        self.contact_client.get_contact_info.return_value = contact
        response = self.client.get("/contact/")
        self.assertEqual(response.status_code, 200)
        self.assertEqual(Contact(**response.json()), contact)
        self.assertEqual(self.contact_client.mock_calls, [call.get_contact_info(CONTACT_ID)])

    async def test_get_verification_not_found(self):
        self.contact_client.get_contact_info.side_effect = ContactDoesNotExist
        response = self.client.get("/contact/")
        self.assertEqual(response.status_code, 404)
        self.assertEqual(response.json(), {"detail": "Contact not found"})
        self.assertEqual(self.contact_client.mock_calls, [call.get_contact_info(CONTACT_ID)])


class GetDomainsTest(ApiTestCase):
    async def test_get_domains(self):
        self.domain_client.get_domains_by_contact.return_value = {
            "domains": [
                {"domain": DomainRef(id=DomainId("c:1"), fqdn="lister.example.com")},
                {"domain": DomainRef(id=DomainId("c:2"), fqdn="rimmer.example.com")},
            ],
            "pagination": None,
        }
        response = self.client.get("/contact/domains/")
        self.assertEqual(response.status_code, 200)
        self.assertEqual(
            response.json(),
            {"results": ["lister.example.com", "rimmer.example.com"], "pagination": None},
        )
        self.assertEqual(
            self.domain_client.mock_calls,
            [
                call.get_domains_by_contact(
                    CONTACT_ID,
                    roles={DomainContactRole.HOLDER},
                    include_deleted=False,
                    order_by="fqdn",
                    page_size=None,
                    page_token=None,
                )
            ],
        )

    async def test_get_domains_contact_not_found(self):
        self.domain_client.get_domains_by_contact.side_effect = ContactDoesNotExist
        response = self.client.get("/contact/domains/")
        self.assertEqual(response.status_code, 404)
        self.assertEqual(response.json(), {"detail": "Contact not found"})
        self.assertEqual(
            self.domain_client.mock_calls,
            [
                call.get_domains_by_contact(
                    CONTACT_ID,
                    roles={DomainContactRole.HOLDER},
                    include_deleted=False,
                    order_by="fqdn",
                    page_size=None,
                    page_token=None,
                )
            ],
        )


class GetRegistrar(ApiTestCase):
    async def test_get_registrar(self):
        contact = make_contact()
        registrar = make_registrar()
        self.contact_client.get_contact_info.return_value = contact
        self.registrar_client.get_registrar_info.return_value = registrar
        response = self.client.get("/contact/registrar/")
        self.assertEqual(response.status_code, 200)
        self.assertEqual(
            RegistrarPublicInfo(**response.json()),
            RegistrarPublicInfo(**registrar.model_dump()),
        )
        self.assertEqual(
            self.registrar_client.mock_calls,
            [call.get_registrar_info(contact.sponsoring_registrar)],
        )

    async def test_get_registrar_contact_not_found(self):
        self.contact_client.get_contact_info.side_effect = ContactDoesNotExist
        response = self.client.get("/contact/registrar/")
        self.assertEqual(response.status_code, 404)
        self.assertEqual(response.json(), {"detail": "Contact not found"})
        self.assertEqual(self.contact_client.mock_calls, [call.get_contact_info(CONTACT_ID)])
        self.assertEqual(self.registrar_client.mock_calls, [])

    async def test_get_registrar_registrar_not_found(self):
        contact = make_contact()
        self.contact_client.get_contact_info.return_value = contact
        self.registrar_client.get_registrar_info.side_effect = RegistrarDoesNotExist
        response = self.client.get("/contact/registrar/")
        self.assertEqual(response.status_code, 404)
        self.assertEqual(response.json(), {"detail": "Registrar not found"})
        self.assertEqual(self.contact_client.mock_calls, [call.get_contact_info(CONTACT_ID)])
        self.assertEqual(
            self.registrar_client.mock_calls,
            [call.get_registrar_info(contact.sponsoring_registrar)],
        )


class ResendInitialMessageTest(ApiTestCase):
    def setUp(self):
        super().setUp()
        self.list_call = call.list(
            contact_id=CONTACT_ID,
            statuses={
                VerificationStatus.CREATED,
                VerificationStatus.INITIALIZED,
                VerificationStatus.ACCESSED,
                VerificationStatus.PENDING,
                VerificationStatus.CONSTRAINED,
                VerificationStatus.FUTILE,
                VerificationStatus.PAUSED,
            },
        )

    async def test_resend_initial_message(self):
        self.contact_client.get_contact_id.return_value = CONTACT_ID
        self.verification_client.list.return_value = PaginatedList[Verification](
            results=[make_verification()]
        )
        self.verification_client.resend_message.return_value = None

        response = self.client.post("/contact/resend_initial/?contact_handle=KRYTEN")

        self.assertEqual(response.status_code, 200)
        self.assertEqual(self.contact_client.mock_calls, [call.get_contact_id("KRYTEN")])
        self.assertEqual(
            self.verification_client.mock_calls,
            [
                self.list_call,
                call.resend_message(VERIFICATION_ID, message_type=MessageType.INITIAL),
            ],
        )
        self.assertLog(
            LogEntryType.RESEND_MESSAGE,
            LoggerResult.SUCCESS,
            input_properties={"contact_handle": "KRYTEN", "type": MessageType.INITIAL.value},
            output_properties={"message_sent": str(True)},
            output_references={
                LogReferenceType.CONTACT: CONTACT_ID,
                LogReferenceType.VERIFICATION: VERIFICATION_ID,
            },
        )

    async def test_resend_initial_message_no_verification(self):
        self.contact_client.get_contact_id.return_value = CONTACT_ID
        self.verification_client.list.return_value = PaginatedList[Verification](results=[])

        response = self.client.post("/contact/resend_initial/?contact_handle=KRYTEN")

        self.assertEqual(response.status_code, 200)
        self.assertEqual(self.contact_client.mock_calls, [call.get_contact_id("KRYTEN")])
        self.assertEqual(self.verification_client.mock_calls, [self.list_call])
        self.assertLog(
            LogEntryType.RESEND_MESSAGE,
            LoggerResult.SUCCESS,
            input_properties={"contact_handle": "KRYTEN", "type": MessageType.INITIAL.value},
            output_properties={"message_sent": str(False)},
            output_references={
                LogReferenceType.CONTACT: CONTACT_ID,
            },
        )

    async def test_contact_not_found(self):
        self.contact_client.get_contact_id.side_effect = ContactDoesNotExist

        response = self.client.post("/contact/resend_initial/?contact_handle=KRYTEN")

        self.assertEqual(response.status_code, 404)
        self.assertEqual(response.json(), {"detail": "Contact not found"})
        self.assertEqual(self.contact_client.mock_calls, [call.get_contact_id("KRYTEN")])
        self.assertEqual(self.verification_client.mock_calls, [])
        self.assertLog(
            LogEntryType.RESEND_MESSAGE,
            LoggerResult.FAIL,
            input_properties={"contact_handle": "KRYTEN", "type": MessageType.INITIAL.value},
            output_properties={"message_sent": str(False), "error": "Contact not found"},
        )

    async def test_incorrect_status(self):
        self.contact_client.get_contact_id.return_value = CONTACT_ID
        self.verification_client.list.return_value = PaginatedList[Verification](
            results=[make_verification()]
        )
        self.verification_client.resend_message.side_effect = IncorrectStatus

        response = self.client.post("/contact/resend_initial/?contact_handle=KRYTEN")

        self.assertEqual(response.status_code, 200)
        self.assertEqual(self.contact_client.mock_calls, [call.get_contact_id("KRYTEN")])
        self.assertEqual(
            self.verification_client.mock_calls,
            [
                self.list_call,
                call.resend_message(VERIFICATION_ID, message_type=MessageType.INITIAL),
            ],
        )
        self.assertLog(
            LogEntryType.RESEND_MESSAGE,
            LoggerResult.FAIL,
            input_properties={"contact_handle": "KRYTEN", "type": MessageType.INITIAL.value},
            output_properties={
                "message_sent": str(False),
                "error": "Incorrect verification status",
            },
            output_references={
                LogReferenceType.CONTACT: CONTACT_ID,
                LogReferenceType.VERIFICATION: VERIFICATION_ID,
            },
        )
